EraSummary

Struct EraSummary 

pub struct EraSummary {
    pub start: EraBound,
    pub end: Option<EraBound>,
    pub params: EraParams,
}

Fields

start: EraBoundend: Option<EraBound>params: EraParams

Implementations

Source

impl EraSummary

pub fn contains_slot( &self, slot: &Slot, tip: &Slot, stability_window: &Slot, ) -> bool

Checks whether the current EraSummary ends after the given slot; In case where the EraSummary doesn’t have any upper bound, then we check whether the point is within a foreseeable horizon.

pub fn contains_slot_unchecked_horizon(&self, slot: &Slot) -> bool

Like contains_slot, but doesn’t enforce anything about the upper bound. So when there’s no upper bound, the slot is simply always considered within the era.

pub fn contains_epoch( &self, epoch: &Epoch, tip: &Slot, stability_window: &Slot, ) -> bool

pub fn contains_epoch_unchecked_horizon(&self, epoch: &Epoch) -> bool

Like contains_epoch, but doesn’t enforce anything about the upper bound. So when there’s no upper bound, the epoch is simply always considered within the era.