pub struct NetworkBlock { /* private fields */ }Expand description
A network block contains:
- An era tag identifying the Cardano era of the block, which determines its exact encoding.
- The block itself, encoded in CBOR format as per the Cardano network protocol.
From a NetworkBlock we can obtain:
- The raw CBOR bytes of the block, wrapped in a
RawBlock. - The decoded
Blockstructure, by decoding the inner CBOR bytes. - The decoded
BlockHeader, by decoding only the header part of the inner CBOR bytes.
Implementations
Sourceimpl NetworkBlock
impl NetworkBlock
pub fn new( era_history: &EraHistory, block: &Block, ) -> Result<Self, EraHistoryError>
pub fn era_tag(&self) -> EraName
pub fn raw_block(&self) -> RawBlock
Sourcepub fn decode_block(&self) -> Result<Block, Error>
pub fn decode_block(&self) -> Result<Block, Error>
Decode the inner block from its raw CBOR representation.
Sourcepub fn decode_header(&self) -> Result<BlockHeader, Error>
pub fn decode_header(&self) -> Result<BlockHeader, Error>
Decode only the header from the raw CBOR representation of the block.