Structs
- Consensus
Parameters - This data type encapsulates the parameters needed by the consensus layer to operate.
- Global
Parameters - Protocol
Parameters - Model from https://github.com/IntersectMBO/formal-ledger-specifications/blob/master/src/Ledger/PParams.lagda Some of the names have been adapted to improve readability. Also see https://github.com/IntersectMBO/cardano-ledger/blob/d90eb4df4651970972d860e95f1a3697a3de8977/eras/conway/impl/cddl-files/conway.cddl#L324