pub struct ConsensusParameters { /* private fields */ }Expand description
This data type encapsulates the parameters needed by the consensus layer to operate.
Implementations
Sourceimpl ConsensusParameters
impl ConsensusParameters
Sourcepub fn new(
global_parameters: GlobalParameters,
era_history: &EraHistory,
ocert_counters: BTreeMap<PoolId, u64>,
) -> Self
pub fn new( global_parameters: GlobalParameters, era_history: &EraHistory, ocert_counters: BTreeMap<PoolId, u64>, ) -> Self
Create new consensus parameters from the given global parameters.
Sourcepub fn create(
randomness_stabilization_window: u64,
slots_per_kes_period: u64,
max_kes_evolution: u64,
active_slot_coeff: f64,
era_history: &EraHistory,
ocert_counters: BTreeMap<PoolId, u64>,
) -> ConsensusParameters
pub fn create( randomness_stabilization_window: u64, slots_per_kes_period: u64, max_kes_evolution: u64, active_slot_coeff: f64, era_history: &EraHistory, ocert_counters: BTreeMap<PoolId, u64>, ) -> ConsensusParameters
Create new consensus parameters from individual values.
pub fn era_history(&self) -> &EraHistory
pub fn randomness_stabilization_window(&self) -> u64
pub fn slot_to_kes_period(&self, slot: Slot) -> u64
pub fn max_kes_evolutions(&self) -> u64
pub fn latest_opcert_sequence_number(&self, pool_id: &PoolId) -> Option<u64>
pub fn active_slot_coeff(&self) -> FixedDecimal