pub struct TransactionBody {Show 20 fields
pub inputs: Set<TransactionInput>,
pub outputs: Vec<MemoizedTransactionOutput>,
pub fee: Lovelace,
pub validity_interval_end: Option<u64>,
pub certificates: Option<NonEmptySet<Certificate>>,
pub withdrawals: Option<NonEmptyKeyValuePairs<RewardAccount, Lovelace>>,
pub auxiliary_data_hash: Option<Bytes>,
pub validity_interval_start: Option<u64>,
pub mint: Option<NonEmptyKeyValuePairs<Hash<CREDENTIAL>, NonEmptyKeyValuePairs<AssetName, NonZeroInt>>>,
pub script_data_hash: Option<Hash<32>>,
pub collateral: Option<NonEmptySet<TransactionInput>>,
pub required_signers: Option<NonEmptySet<Hash<KEY>>>,
pub network_id: Option<NetworkId>,
pub collateral_return: Option<MemoizedTransactionOutput>,
pub total_collateral: Option<Lovelace>,
pub reference_inputs: Option<NonEmptySet<TransactionInput>>,
pub votes: Option<NonEmptyKeyValuePairs<Voter, NonEmptyKeyValuePairs<ProposalId, VotingProcedure>>>,
pub proposals: Option<NonEmptySet<Proposal>>,
pub treasury_value: Option<Lovelace>,
pub donation: Option<PositiveCoin>,
/* private fields */
}Expand description
A multi-era transaction body. This type is meant to represent all transaction body in eras that we may encounter.
Fields
inputs: Set<TransactionInput>outputs: Vec<MemoizedTransactionOutput>fee: Lovelacevalidity_interval_end: Option<u64>certificates: Option<NonEmptySet<Certificate>>withdrawals: Option<NonEmptyKeyValuePairs<RewardAccount, Lovelace>>auxiliary_data_hash: Option<Bytes>validity_interval_start: Option<u64>mint: Option<NonEmptyKeyValuePairs<Hash<CREDENTIAL>, NonEmptyKeyValuePairs<AssetName, NonZeroInt>>>script_data_hash: Option<Hash<32>>collateral: Option<NonEmptySet<TransactionInput>>required_signers: Option<NonEmptySet<Hash<KEY>>>network_id: Option<NetworkId>collateral_return: Option<MemoizedTransactionOutput>total_collateral: Option<Lovelace>reference_inputs: Option<NonEmptySet<TransactionInput>>votes: Option<NonEmptyKeyValuePairs<Voter, NonEmptyKeyValuePairs<ProposalId, VotingProcedure>>>proposals: Option<NonEmptySet<Proposal>>treasury_value: Option<Lovelace>donation: Option<PositiveCoin>Implementations
Sourceimpl TransactionBody
impl TransactionBody
pub const HASH_SIZE: usize = 32
Sourcepub fn id(&self) -> Hash<{ Self::HASH_SIZE }>
pub fn id(&self) -> Hash<{ Self::HASH_SIZE }>
The original id (i.e. blake2b-256 hash digest) of the transaction body. Note that the hash computed from the original bytes and memoized; it is not re-computed from re-serialised data.
pub fn len(&self) -> u64