Module bytes

Module bytes 

Newtypes for &[u8], [u8;N] and Vec<u8>.

To support specialised encoding and decoding of byte slices, byte arrays, and vectors which are represented as CBOR bytes instead of arrays of u8s, the types ByteSlice, ByteArray and ByteVec (requires feature “alloc”) are provided. These implement Encode and Decode by translating to and from CBOR bytes.

If the feature “derive” is present, specialised traits EncodeBytes and DecodeBytes are also provided. These are implemented for the aforementioned newtypes as well as for their Option variations, regular &[u8], [u8; N], Vec<u8> and for Cow<'_, [u8]> if the alloc feature is given. They enable the direct use of &[u8], [u8; N], Vec<u8> and Cow<'_, [u8]> in types deriving Encode and Decode if used with a #[cbor(with = "minicbor::bytes")] annotation.

Structs

ByteArray
Newtype for [u8; N].
ByteSlice
Newtype for [u8].
ByteVec
Newtype for Vec<u8>.

Traits

CborLenBytes
Like CborLen but specific for byte slices.
DecodeBytes
Like Decode but specific for decoding from byte slices.
EncodeBytes
Like Encode but specific for encoding of byte slices.

Functions

cbor_len
decode
Freestanding function calling DecodeBytes::decode_bytes.
encode
Freestanding function calling EncodeBytes::encode_bytes.
is_nil
nil