pub enum Size {
Head,
Bytes(u64),
Items(u64),
Indef,
}Expand description
Information about a CBOR item size.
Usage example
use minicbor::decode::info::Size;
let val = vec![1, 2, 3, 4, 5];
let cbor = minicbor::to_vec(val)?;
let hlen = Size::head(cbor[0])?;
let size = Size::tail(&cbor[.. hlen])?;
assert_eq!(Size::Items(5), size);Variants
Head
The item consists only of the head.
Bytes(u64)
The item is some text or byte string with the given number of bytes.
Items(u64)
The item is an array or map with the given number of items.
Indef
The item is an indefinite value.
Implementations