missing_field

Function missing_field 

pub fn missing_field<C, A>(field_tag: u8) -> Error
where C: ?Sized,
Yield a PartialDecoder that fails with a comprehensible error message when an expected field is missing from the map.