LazyDecoder

Struct LazyDecoder 

pub struct LazyDecoder<'a> { /* private fields */ }
A decoder that only consumes bytes CHUNK_SIZE at a time. Useful to decode large files while maintaining memory usage low.

The decoder keeps an internal state with the bytes that have been read but not consumed, and a handle to a source that implements std::io::Read.

See Self::from_file for example, to lazily read and decode from a (large) file.

Implementations

Source

impl<'a> LazyDecoder<'a>

pub fn from_file(file: &'a mut File) -> LazyDecoder<'a>

pub fn skip(&mut self) -> Result<(), Box<dyn Error>>

Consumes enough bytes and skip the next CBOR element.

pub fn decode<T>(&mut self) -> Result<T, Box<dyn Error>>
where T: for<'d> Decode<'d, ()>,

Consumes enough bytes and decode the next CBOR element.

pub fn with_decoder<T>( &mut self, decode: impl Fn(&mut Decoder<'_>) -> Result<T, Box<dyn Error>>, ) -> Result<T, Box<dyn Error>>

Decode some element according to a custom strategy. This consumes more bytes if the decoder fails due to a lack of bytes. And error otherwise.