Encoder

Struct Encoder 

pub struct Encoder<W> { /* private fields */ }
A non-allocating CBOR encoder writing encoded bytes to the given Write sink.

Implementations

Source

impl<W> Encoder<W>
where W: Write,

pub fn new(writer: W) -> Encoder<W>

Construct an Encoder that writes to the given Write sink.

pub fn writer(&self) -> &W

Access the inner writer.

pub fn writer_mut(&mut self) -> &mut W

Get mutable access to the inner writer.

pub fn into_writer(self) -> W

Get back the Write impl.

pub fn encode<T>( &mut self, x: T, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>
where T: Encode<()>,

Encode any type that implements Encode.

pub fn encode_with<C, T>( &mut self, x: T, ctx: &mut C, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>
where T: Encode<C>,

Encode any type that implements Encode.

pub fn u8( &mut self, x: u8, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a u8 value.

pub fn i8( &mut self, x: i8, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode an i8 value.

pub fn u16( &mut self, x: u16, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a u16 value.

pub fn i16( &mut self, x: i16, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode an i16 value.

pub fn u32( &mut self, x: u32, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a u32 value.

pub fn i32( &mut self, x: i32, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode an i32 value.

pub fn u64( &mut self, x: u64, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a u64 value.

pub fn i64( &mut self, x: i64, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode an i64 value.

pub fn int( &mut self, x: Int, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a CBOR integer.

See Int for details regarding the value range of CBOR integers.

pub fn null(&mut self) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a CBOR null value.

pub fn undefined( &mut self, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a CBOR undefined value.

pub fn simple( &mut self, x: u8, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a CBOR simple value.

pub fn f16( &mut self, x: f32, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode an f32 value as a half float (f16).

Requires feature "half".

NB: The conversion from f32 to f16 is potentially lossy. Generally values are truncated and rounded to the nearest 16-bit value, except:

  • 32-bit values which do not fit into 16 bit become ±∞.
  • 32-bit subnormal values become ±0.
  • Exponents smaller than the min. 16-bit exponent become 16-bit subnormals or ±0.

For further details please consult the half crate which is used internally for f16 support.

pub fn f32( &mut self, x: f32, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode an f32 value.

pub fn f64( &mut self, x: f64, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode an f64 value.

pub fn bool( &mut self, x: bool, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a bool value.

pub fn char( &mut self, x: char, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a char value.

pub fn tag<T>( &mut self, x: T, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>
where T: Into<Tag>,

Encode a CBOR tag.

pub fn bytes( &mut self, x: &[u8], ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a byte slice.

pub fn str( &mut self, x: &str, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Encode a string slice.

pub fn array( &mut self, len: u64, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Begin encoding an array with len elements.

pub fn map( &mut self, len: u64, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Begin encoding a map with len entries.

pub fn begin_array( &mut self, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Begin encoding an array of unknown size.

Use Encoder::end to terminate the array.

pub fn begin_bytes( &mut self, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Begin encoding an indefinite number of byte slices.

Use Encoder::end to terminate.

pub fn begin_map( &mut self, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Begin encoding a map of unknown size.

Use Encoder::end to terminate the map.

pub fn begin_str( &mut self, ) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Begin encoding an indefinite number of string slices.

Use Encoder::end to terminate.

pub fn end(&mut self) -> Result<&mut Encoder<W>, Error<<W as Write>::Error>>

Terminate an indefinite collection.

pub fn ok(&mut self) -> Result<(), Error<<W as Write>::Error>>

Syntactic sugar for Ok(()).

pub fn tokens<'a, 'b, I>( &mut self, tokens: I, ) -> Result<(), Error<<W as Write>::Error>>
where 'b: 'a, I: IntoIterator<Item = &'a Token<'b>>,

Encode a sequence of CBOR tokens.