Decode

Trait Decode 

pub trait Decode<'b, C>: Sized {
    // Required method
    fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Self, Error>;

    // Provided method
    fn nil() -> Option<Self> { ... }
}
A type that can be decoded from CBOR.

Required Methods

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Self, Error>

Decode a value using the given Decoder.

In addition to the decoder a user provided decoding context is given as another parameter. Most implementations of this trait do not need a decoding context and should be completely generic in the context type. In cases where a context is needed and the Decode impl type is meant to be combined with other types that require a different context type, it is preferrable to constrain the context type variable C with a trait bound instead of fixing the type.

Provided Methods

fn nil() -> Option<Self>

If possible, return a nil value of Self.

This method is primarily used by minicbor-derive and allows creating a special value denoting the absence of a “real” value if no CBOR value is present. The canonical example of a type where this is sensible is the Option type, whose Decode::nil method would return Some(None).

With the exception of Option<_> all types T are considered mandatory by default, i.e. T::nil() returns None. Missing values of T therefore cause decoding errors in derived Decode implementations.

NB: A type implementing Decode with an overriden Decode::nil method should also override Encode::is_nil if it implements Encode at all.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl<'a, 'b, C> Decode<'b, C> for &'a str
where 'b: 'a,

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<&'a str, Error>

Source

impl<'a, 'b, C> Decode<'b, C> for &'a CStr
where 'b: 'a,

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<&'a CStr, Error>

Source

impl<'a, 'b, C> Decode<'b, C> for &'a Path
where 'b: 'a,

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<&'a Path, Error>

Source

impl<'b, C> Decode<'b, C> for IpAddr

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<IpAddr, Error>

Source

impl<'b, C> Decode<'b, C> for SocketAddr

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<SocketAddr, Error>

Source

impl<'b, C> Decode<'b, C> for AddrDistr

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<AddrDistr, Error>

Source

impl<'b, C> Decode<'b, C> for SpendingData

Source

impl<'b, C> Decode<'b, C> for AnyUInt

Source

fn decode(d: &mut Decoder<'b>, _ctx: &mut C) -> Result<AnyUInt, Error>

Source

impl<'b, C> Decode<'b, C> for AuxiliaryData

Source

impl<'b, C> Decode<'b, C> for Certificate

Source

impl<'b, C> Decode<'b, C> for InstantaneousRewardSource

Source

impl<'b, C> Decode<'b, C> for InstantaneousRewardTarget

Source

impl<'b, C> Decode<'b, C> for Value

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Value, Error>

Source

impl<'b, C> Decode<'b, C> for BlockSig

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<BlockSig, Error>

Source

impl<'b, C> Decode<'b, C> for Ssc

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Ssc, Error>

Source

impl<'b, C> Decode<'b, C> for SscProof

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<SscProof, Error>

Source

impl<'b, C> Decode<'b, C> for Twit

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Twit, Error>

Source

impl<'b, C> Decode<'b, C> for TxFeePol

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<TxFeePol, Error>

Source

impl<'b, C> Decode<'b, C> for TxIn

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<TxIn, Error>

Source

impl<'b, C> Decode<'b, C> for Metadatum

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Metadatum, Error>

Source

impl<'b, C> Decode<'b, C> for bool

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<bool, Error>

Source

impl<'b, C> Decode<'b, C> for char

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<char, Error>

Source

impl<'b, C> Decode<'b, C> for f32

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<f32, Error>

Source

impl<'b, C> Decode<'b, C> for f64

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<f64, Error>

Source

impl<'b, C> Decode<'b, C> for i8

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<i8, Error>

Source

impl<'b, C> Decode<'b, C> for i16

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<i16, Error>

Source

impl<'b, C> Decode<'b, C> for i32

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<i32, Error>

Source

impl<'b, C> Decode<'b, C> for i64

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<i64, Error>

Source

impl<'b, C> Decode<'b, C> for isize

Available on 32-bit only.
Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<isize, Error>

Source

impl<'b, C> Decode<'b, C> for u8

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<u8, Error>

Source

impl<'b, C> Decode<'b, C> for u16

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<u16, Error>

Source

impl<'b, C> Decode<'b, C> for u32

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<u32, Error>

Source

impl<'b, C> Decode<'b, C> for u64

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<u64, Error>

Source

impl<'b, C> Decode<'b, C> for ()

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<(), Error>

Source

impl<'b, C> Decode<'b, C> for usize

Available on 32-bit only.
Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<usize, Error>

Source

impl<'b, C> Decode<'b, C> for Box<str>

Available on crate feature alloc only.
Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<Box<str>, Error>

Source

impl<'b, C> Decode<'b, C> for Box<Path>

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Box<Path>, Error>

Source

impl<'b, C> Decode<'b, C> for CString

Available on crate feature alloc only.
Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<CString, Error>

Source

impl<'b, C> Decode<'b, C> for String

Available on crate feature alloc only.
Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<String, Error>

Source

impl<'b, C> Decode<'b, C> for Ipv4Addr

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Ipv4Addr, Error>

Source

impl<'b, C> Decode<'b, C> for Ipv6Addr

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Ipv6Addr, Error>

Source

impl<'b, C> Decode<'b, C> for SocketAddrV4

Available on crate feature std only.
Source

impl<'b, C> Decode<'b, C> for SocketAddrV6

Available on crate feature std only.
Source

impl<'b, C> Decode<'b, C> for NonZero<i8>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<i8>, Error>

Source

impl<'b, C> Decode<'b, C> for NonZero<i16>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<i16>, Error>

Source

impl<'b, C> Decode<'b, C> for NonZero<i32>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<i32>, Error>

Source

impl<'b, C> Decode<'b, C> for NonZero<i64>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<i64>, Error>

Source

impl<'b, C> Decode<'b, C> for NonZero<isize>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<isize>, Error>

Source

impl<'b, C> Decode<'b, C> for NonZero<u8>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<u8>, Error>

Source

impl<'b, C> Decode<'b, C> for NonZero<u16>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<u16>, Error>

Source

impl<'b, C> Decode<'b, C> for NonZero<u32>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<u32>, Error>

Source

impl<'b, C> Decode<'b, C> for NonZero<u64>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<u64>, Error>

Source

impl<'b, C> Decode<'b, C> for NonZero<usize>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonZero<usize>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<bool>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<bool>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<i8>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<i8>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<i16>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<i16>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<i32>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<i32>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<i64>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<i64>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<isize>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<isize>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<u8>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<u8>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<u16>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<u16>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<u32>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<u32>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<u64>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<u64>, Error>

Source

impl<'b, C> Decode<'b, C> for Atomic<usize>

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Atomic<usize>, Error>

Source

impl<'b, C> Decode<'b, C> for Duration

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Duration, Error>

Source

impl<'b, C> Decode<'b, C> for PathBuf

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<PathBuf, Error>

Source

impl<'b, C> Decode<'b, C> for SystemTime

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<SystemTime, Error>

Source

impl<'b, C> Decode<'b, C> for EmptyMap

Source

fn decode(d: &mut Decoder<'b>, _ctx: &mut C) -> Result<EmptyMap, Error>

Source

impl<'b, C> Decode<'b, C> for BoundedBytes

Source

impl<'b, C, I, const T: u64> Decode<'b, C> for TagWrap<I, T>
where I: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<TagWrap<I, T>, Error>

Source

impl<'b, C, K, V> Decode<'b, C> for KeyValuePairs<K, V>
where K: Decode<'b, C> + Clone, V: Decode<'b, C> + Clone,

Source

fn decode( d: &mut Decoder<'b>, ctx: &mut C, ) -> Result<KeyValuePairs<K, V>, Error>

Source

impl<'b, C, K, V> Decode<'b, C> for NonEmptyKeyValuePairs<K, V>
where K: Decode<'b, C> + Clone, V: Decode<'b, C> + Clone,

Source

fn decode( d: &mut Decoder<'b>, ctx: &mut C, ) -> Result<NonEmptyKeyValuePairs<K, V>, Error>

Source

impl<'b, C, K, V> Decode<'b, C> for BTreeMap<K, V>
where K: Decode<'b, C> + Eq + Ord, V: Decode<'b, C>,

Available on crate feature alloc only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<BTreeMap<K, V>, Error>

Source

impl<'b, C, K, V, S> Decode<'b, C> for HashMap<K, V, S>
where K: Decode<'b, C> + Eq + Hash, V: Decode<'b, C>, S: BuildHasher + Default,

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<HashMap<K, V, S>, Error>

Source

impl<'b, C, P> Decode<'b, C> for OrderPreservingProperties<P>
where P: Decode<'b, C>,

Source

impl<'b, C, T> Decode<'b, C> for Cow<'_, T>
where T: ToOwned + ?Sized, <T as ToOwned>::Owned: Decode<'b, C>,

Available on crate feature alloc only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Cow<'_, T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for Bound<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Bound<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for Option<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Option<T>, Error>

Source

fn nil() -> Option<Option<T>>

Source

impl<'b, C, T> Decode<'b, C> for Nullable<T>
where T: Decode<'b, C> + Clone,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Nullable<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for PseudoDatumOption<T>
where T: Decode<'b, C>,

Source

fn decode( d: &mut Decoder<'b>, ctx: &mut C, ) -> Result<PseudoDatumOption<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for PseudoScript<T>
where T: Decode<'b, ()>,

Source

fn decode(d: &mut Decoder<'b>, _ctx: &mut C) -> Result<PseudoScript<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for PseudoTransactionOutput<T>
where T: Decode<'b, C>,

Source

impl<'b, C, T> Decode<'b, C> for PseudoScript<T>
where T: Decode<'b, ()>,

Source

fn decode(d: &mut Decoder<'b>, _ctx: &mut C) -> Result<PseudoScript<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for PseudoTransactionOutput<T>
where T: Decode<'b, C>,

Source

impl<'b, C, T> Decode<'b, C> for Box<T>
where T: Decode<'b, C>,

Available on crate feature alloc only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Box<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for BinaryHeap<T>
where T: Decode<'b, C> + Ord,

Available on crate feature alloc only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<BinaryHeap<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for BTreeSet<T>
where T: Decode<'b, C> + Ord,

Available on crate feature alloc only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<BTreeSet<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for LinkedList<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<LinkedList<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for VecDeque<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<VecDeque<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for Vec<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Vec<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for Cell<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Cell<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for RefCell<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<RefCell<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for PhantomData<T>

Source

fn decode(d: &mut Decoder<'b>, _: &mut C) -> Result<PhantomData<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for Wrapping<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Wrapping<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for Range<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Range<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for RangeFrom<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<RangeFrom<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for RangeInclusive<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<RangeInclusive<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for RangeTo<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<RangeTo<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for RangeToInclusive<T>
where T: Decode<'b, C>,

Source

fn decode( d: &mut Decoder<'b>, ctx: &mut C, ) -> Result<RangeToInclusive<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for CborWrap<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<CborWrap<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for NonEmptySet<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<NonEmptySet<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for Set<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Set<T>, Error>

Source

impl<'b, C, T> Decode<'b, C> for ZeroOrOneArray<T>
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<ZeroOrOneArray<T>, Error>

Source

impl<'b, C, T, E> Decode<'b, C> for Result<T, E>
where T: Decode<'b, C>, E: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<Result<T, E>, Error>

Source

impl<'b, C, T, S> Decode<'b, C> for HashSet<T, S>
where T: Decode<'b, C> + Eq + Hash, S: BuildHasher + Default,

Available on crate feature std only.
Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<HashSet<T, S>, Error>

Source

impl<'b, C, T, const N: usize> Decode<'b, C> for [T; N]
where T: Decode<'b, C>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut C) -> Result<[T; N], Error>

Source

impl<'b, C, const N: usize> Decode<'b, C> for SkipCbor<N>

Source

fn decode(d: &mut Decoder<'b>, _ctx: &mut C) -> Result<SkipCbor<N>, Error>

Source

impl<'b, Ctx, A> Decode<'b, Ctx> for (A,)
where A: Decode<'b, Ctx>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut Ctx) -> Result<(A,), Error>

Source

impl<'b, Ctx, A, B> Decode<'b, Ctx> for (A, B)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>,

Source

fn decode(d: &mut Decoder<'b>, ctx: &mut Ctx) -> Result<(A, B), Error>

Source

impl<'b, Ctx, A, B, C> Decode<'b, Ctx> for (A, B, C)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D> Decode<'b, Ctx> for (A, B, C, D)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E> Decode<'b, Ctx> for (A, B, C, D, E)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F> Decode<'b, Ctx> for (A, B, C, D, E, F)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G> Decode<'b, Ctx> for (A, B, C, D, E, F, G)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G, H> Decode<'b, Ctx> for (A, B, C, D, E, F, G, H)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>, H: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G, H, I> Decode<'b, Ctx> for (A, B, C, D, E, F, G, H, I)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>, H: Decode<'b, Ctx>, I: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G, H, I, J> Decode<'b, Ctx> for (A, B, C, D, E, F, G, H, I, J)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>, H: Decode<'b, Ctx>, I: Decode<'b, Ctx>, J: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G, H, I, J, K> Decode<'b, Ctx> for (A, B, C, D, E, F, G, H, I, J, K)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>, H: Decode<'b, Ctx>, I: Decode<'b, Ctx>, J: Decode<'b, Ctx>, K: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G, H, I, J, K, L> Decode<'b, Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>, H: Decode<'b, Ctx>, I: Decode<'b, Ctx>, J: Decode<'b, Ctx>, K: Decode<'b, Ctx>, L: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M> Decode<'b, Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>, H: Decode<'b, Ctx>, I: Decode<'b, Ctx>, J: Decode<'b, Ctx>, K: Decode<'b, Ctx>, L: Decode<'b, Ctx>, M: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N> Decode<'b, Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>, H: Decode<'b, Ctx>, I: Decode<'b, Ctx>, J: Decode<'b, Ctx>, K: Decode<'b, Ctx>, L: Decode<'b, Ctx>, M: Decode<'b, Ctx>, N: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> Decode<'b, Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>, H: Decode<'b, Ctx>, I: Decode<'b, Ctx>, J: Decode<'b, Ctx>, K: Decode<'b, Ctx>, L: Decode<'b, Ctx>, M: Decode<'b, Ctx>, N: Decode<'b, Ctx>, O: Decode<'b, Ctx>,

Source

impl<'b, Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> Decode<'b, Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)
where A: Decode<'b, Ctx>, B: Decode<'b, Ctx>, C: Decode<'b, Ctx>, D: Decode<'b, Ctx>, E: Decode<'b, Ctx>, F: Decode<'b, Ctx>, G: Decode<'b, Ctx>, H: Decode<'b, Ctx>, I: Decode<'b, Ctx>, J: Decode<'b, Ctx>, K: Decode<'b, Ctx>, L: Decode<'b, Ctx>, M: Decode<'b, Ctx>, N: Decode<'b, Ctx>, O: Decode<'b, Ctx>, P: Decode<'b, Ctx>,

Source

impl<'bytes, 'b, Ctx> Decode<'bytes, Ctx> for MintedBlock<'b>
where 'bytes: 'b,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MintedBlock<'b>, Error>

Source

impl<'bytes, 'b, Ctx> Decode<'bytes, Ctx> for MintedTx<'b>
where 'bytes: 'b,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MintedTx<'b>, Error>

Source

impl<'bytes, 'b, Ctx> Decode<'bytes, Ctx> for MintedWitnessSet<'b>
where 'bytes: 'b,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MintedWitnessSet<'b>, Error>

Source

impl<'bytes, 'b, Ctx> Decode<'bytes, Ctx> for MintedWitnessSet<'b>
where 'bytes: 'b,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MintedWitnessSet<'b>, Error>

Source

impl<'bytes, 'b, Ctx> Decode<'bytes, Ctx> for MintedBlock<'b>
where 'bytes: 'b,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MintedBlock<'b>, Error>

Source

impl<'bytes, 'b, Ctx> Decode<'bytes, Ctx> for MintedBlockBody<'b>
where 'bytes: 'b,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MintedBlockBody<'b>, Error>

Source

impl<'bytes, 'b, Ctx> Decode<'bytes, Ctx> for MintedEbBlock<'b>
where 'bytes: 'b,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MintedEbBlock<'b>, Error>

Source

impl<'bytes, 'b, Ctx> Decode<'bytes, Ctx> for MintedTxPayload<'b>
where 'bytes: 'b,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MintedTxPayload<'b>, Error>

Source

impl<'bytes, 'b, Ctx> Decode<'bytes, Ctx> for MintedWitnessSet<'b>
where 'bytes: 'b,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MintedWitnessSet<'b>, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Language

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Language, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for RedeemerTag

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<RedeemerTag, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Language

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Language, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for NonceVariant

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<NonceVariant, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Block

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Block, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for HeaderBody

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<HeaderBody, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for MoveInstantaneousReward

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<MoveInstantaneousReward, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for PostAlonzoAuxiliaryData

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PostAlonzoAuxiliaryData, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for ProtocolParamUpdate

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<ProtocolParamUpdate, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Redeemer

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Redeemer, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for RedeemerPointer

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<RedeemerPointer, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for ShelleyMaAuxiliaryData

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<ShelleyMaAuxiliaryData, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for TransactionBody

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<TransactionBody, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for TransactionOutput

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<TransactionOutput, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Tx

Source

fn decode(__d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx) -> Result<Tx, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Update

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Update, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for WitnessSet

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<WitnessSet, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for CostModels

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<CostModels, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for OperationalCert

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<OperationalCert, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for PostAlonzoAuxiliaryData

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PostAlonzoAuxiliaryData, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for ProtocolParamUpdate

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<ProtocolParamUpdate, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Update

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Update, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for WitnessSet

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<WitnessSet, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Address

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Address, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for BVerMod

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<BVerMod, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Block

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Block, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for BlockBody

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<BlockBody, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for BlockCons

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<BlockCons, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for BlockHead

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<BlockHead, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for BlockHeadEx

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<BlockHeadEx, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for BlockProof

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<BlockProof, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Dlg

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Dlg, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for EbBlock

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<EbBlock, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for EbbCons

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<EbbCons, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for EbbHead

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<EbbHead, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Lwdlg

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Lwdlg, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for SlotId

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<SlotId, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Tx

Source

fn decode(__d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx) -> Result<Tx, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for TxOut

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<TxOut, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for TxPayload

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<TxPayload, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Up

Source

fn decode(__d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx) -> Result<Up, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for UpProp

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<UpProp, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for UpVote

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<UpVote, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for PostAlonzoAuxiliaryData

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PostAlonzoAuxiliaryData, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for RedeemersValue

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<RedeemersValue, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Update

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Update, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for WitnessSet

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<WitnessSet, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for ExUnitPrices

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<ExUnitPrices, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Nonce

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<Nonce, Error>

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for VrfCert

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<VrfCert, Error>

Source

impl<'bytes, Ctx, T1> Decode<'bytes, Ctx> for PseudoHeader<T1>
where T1: Decode<'bytes, Ctx>,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PseudoHeader<T1>, Error>

Source

impl<'bytes, Ctx, T1> Decode<'bytes, Ctx> for PseudoHeader<T1>
where T1: Decode<'bytes, Ctx>,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PseudoHeader<T1>, Error>

Source

impl<'bytes, Ctx, T1> Decode<'bytes, Ctx> for PseudoTransactionBody<T1>
where T1: Decode<'bytes, Ctx>,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PseudoTransactionBody<T1>, Error>

Source

impl<'bytes, Ctx, T1> Decode<'bytes, Ctx> for PseudoTransactionBody<T1>
where T1: Decode<'bytes, Ctx>,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PseudoTransactionBody<T1>, Error>

Source

impl<'bytes, Ctx, T1, T2, T3> Decode<'bytes, Ctx> for PseudoPostAlonzoTransactionOutput<T1, T2, T3>
where T1: Decode<'bytes, Ctx>, T2: Decode<'bytes, Ctx>, T3: Decode<'bytes, Ctx>,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PseudoPostAlonzoTransactionOutput<T1, T2, T3>, Error>

Source

impl<'bytes, Ctx, T1, T2, T3> Decode<'bytes, Ctx> for PseudoTx<T1, T2, T3>
where T1: Decode<'bytes, Ctx> + Clone, T2: Decode<'bytes, Ctx> + Clone, T3: Decode<'bytes, Ctx> + Clone,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PseudoTx<T1, T2, T3>, Error>

Source

impl<'bytes, Ctx, T1, T2, T3> Decode<'bytes, Ctx> for PseudoTx<T1, T2, T3>
where T1: Decode<'bytes, Ctx> + Clone, T2: Decode<'bytes, Ctx> + Clone, T3: Decode<'bytes, Ctx> + Clone,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PseudoTx<T1, T2, T3>, Error>

Source

impl<'bytes, Ctx, T1, T2, T3, T4> Decode<'bytes, Ctx> for PseudoBlock<T1, T2, T3, T4>
where T1: Decode<'bytes, Ctx>, T2: Decode<'bytes, Ctx>, T3: Decode<'bytes, Ctx>, T4: Decode<'bytes, Ctx> + Clone,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PseudoBlock<T1, T2, T3, T4>, Error>

Source

impl<'bytes, Ctx, T1, T2, T3, T4> Decode<'bytes, Ctx> for PseudoBlock<T1, T2, T3, T4>
where T1: Decode<'bytes, Ctx>, T2: Decode<'bytes, Ctx>, T3: Decode<'bytes, Ctx>, T4: Decode<'bytes, Ctx> + Clone,

Source

fn decode( __d777: &mut Decoder<'bytes>, __ctx777: &mut Ctx, ) -> Result<PseudoBlock<T1, T2, T3, T4>, Error>

Implementors

Source

impl<'a, 'b, C> Decode<'b, C> for &'a ByteSlice
where 'b: 'a,

Source

impl<'a, C, const BYTES: usize> Decode<'a, C> for Hash<BYTES>

Source

impl<'b> Decode<'b, ()> for Point

Source

impl<'b> Decode<'b, ()> for NetworkBlock

Source

impl<'b> Decode<'b, ()> for Tip

Source

impl<'b> Decode<'b, Slot> for EraHistory

Source

impl<'b, C> Decode<'b, C> for EraName

Source

impl<'b, C> Decode<'b, C> for MemoizedDatum

Source

impl<'b, C> Decode<'b, C> for amaru_kernel::cardano::metadatum::Metadatum

FIXME: Multi-era + length checks on bytes and text

Ensure that this decoder is multi-era capable and also correctly checks for bytes and (utf-8-encoded) text to be encoded as chunks.

Source

impl<'b, C> Decode<'b, C> for RewardKind

Source

impl<'b, C> Decode<'b, C> for AddrAttrProperty

Source

impl<'b, C> Decode<'b, C> for AddrType

Source

impl<'b, C> Decode<'b, C> for BigInt

Source

impl<'b, C> Decode<'b, C> for amaru_kernel::Certificate

Source

impl<'b, C> Decode<'b, C> for DRep

Source

impl<'b, C> Decode<'b, C> for GovAction

Source

impl<'b, C> Decode<'b, C> for NativeScript

Source

impl<'b, C> Decode<'b, C> for PlutusData

Source

impl<'b, C> Decode<'b, C> for Redeemers

Source

impl<'b, C> Decode<'b, C> for Relay

Source

impl<'b, C> Decode<'b, C> for StakeCredential

Source

impl<'b, C> Decode<'b, C> for amaru_kernel::Value

Source

impl<'b, C> Decode<'b, C> for Vote

Source

impl<'b, C> Decode<'b, C> for Voter

Source

impl<'b, C> Decode<'b, C> for Token<'b>

Source

impl<'b, C> Decode<'b, C> for Account

Source

impl<'b, C> Decode<'b, C> for amaru_kernel::cardano::auxiliary_data::AuxiliaryData

Source

impl<'b, C> Decode<'b, C> for amaru_kernel::cardano::block::Block

Source

impl<'b, C> Decode<'b, C> for BlockHeader

Source

impl<'b, C> Decode<'b, C> for BlockHeight

Source

impl<'b, C> Decode<'b, C> for CertificatePointer

Source

impl<'b, C> Decode<'b, C> for DRepState

Source

impl<'b, C> Decode<'b, C> for Epoch

Source

impl<'b, C> Decode<'b, C> for EraBound

Source

impl<'b, C> Decode<'b, C> for EraParams

Source

impl<'b, C> Decode<'b, C> for EraSummary

Source

impl<'b, C> Decode<'b, C> for MemoizedNativeScript

Source

impl<'b, C> Decode<'b, C> for MemoizedPlutusData

Source

impl<'b, C> Decode<'b, C> for MemoizedTransactionOutput

Source

impl<'b, C> Decode<'b, C> for NetworkMagic

Source

impl<'b, C> Decode<'b, C> for PoolParams

Source

impl<'b, C> Decode<'b, C> for ProposalPointer

Source

impl<'b, C> Decode<'b, C> for ProposalState

Source

impl<'b, C> Decode<'b, C> for ProtocolParameters

Source

impl<'b, C> Decode<'b, C> for Reward

Source

impl<'b, C> Decode<'b, C> for Slot

Source

impl<'b, C> Decode<'b, C> for amaru_kernel::cardano::transaction_body::TransactionBody

Source

impl<'b, C> Decode<'b, C> for TransactionPointer

Source

impl<'b, C> Decode<'b, C> for Anchor

Source

impl<'b, C> Decode<'b, C> for Constitution

Source

impl<'b, C> Decode<'b, C> for DRepVotingThresholds

Source

impl<'b, C> Decode<'b, C> for NonZeroInt

Source

impl<'b, C> Decode<'b, C> for PoolVotingThresholds

Source

impl<'b, C> Decode<'b, C> for PositiveCoin

Source

impl<'b, C> Decode<'b, C> for ProposalProcedure

Source

impl<'b, C> Decode<'b, C> for GovActionId

Source

impl<'b, C> Decode<'b, C> for RationalNumber

Source

impl<'b, C> Decode<'b, C> for VotingProcedure

Source

impl<'b, C> Decode<'b, C> for SerialisedAsMillis

Source

impl<'b, C> Decode<'b, C> for SerialisedAsPico

Source

impl<'b, C> Decode<'b, C> for amaru_kernel::cbor::data::Int

Source

impl<'b, C> Decode<'b, C> for AnyCbor

Source

impl<'b, C> Decode<'b, C> for Tag

Source

impl<'b, C, A> Decode<'b, C> for MaybeIndefArray<A>
where A: Decode<'b, C>,

Source

impl<'b, C, A> Decode<'b, C> for Constr<A>
where A: Decode<'b, C>,

Source

impl<'b, C, const N: u64, T> Decode<'b, C> for Tagged<N, T>
where T: Decode<'b, C>,

Source

impl<'b, C, const N: usize> Decode<'b, C> for ByteArray<N>

Source

impl<'b, T, C> Decode<'b, C> for KeepRaw<'b, T>
where T: Decode<'b, C>,

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for amaru_kernel::Language

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for NetworkId

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for amaru_kernel::ScriptPurpose

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Transaction

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for amaru_kernel::cardano::witness_set::WitnessSet

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for AddressPayload

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for BootstrapWitness

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for ByronAddress

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for Bytes

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for amaru_kernel::CostModels

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for amaru_kernel::ExUnitPrices

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for ExUnits

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for amaru_kernel::HeaderBody

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for amaru_kernel::Int

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for PoolMetadata

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for amaru_kernel::ProtocolParamUpdate

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for amaru_kernel::Redeemer

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for RedeemersKey

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for TransactionInput

Source

impl<'bytes, Ctx> Decode<'bytes, Ctx> for VKeyWitness

Source

impl<'bytes, Ctx, const VERSION: usize> Decode<'bytes, Ctx> for PlutusScript<VERSION>

Source

impl<'d, C> Decode<'d, C> for ConstitutionalCommitteeStatus

Source

impl<'d, C> Decode<'d, C> for Ballot

Source

impl<'d, C> Decode<'d, C> for BallotId

Source

impl<'d, C> Decode<'d, C> for ComparableProposalId

Source

impl<C> Decode<'_, C> for ByteVec

Available on crate feature alloc only.