Encode

Trait Encode 

pub trait Encode<C> {
    // Required method
    fn encode<W>(
        &self,
        e: &mut Encoder<W>,
        ctx: &mut C,
    ) -> Result<(), Error<<W as Write>::Error>>
       where W: Write;

    // Provided method
    fn is_nil(&self) -> bool { ... }
}
A type that can be encoded to CBOR.

If this type’s CBOR encoding is meant to be decoded by Decode impls derived with minicbor_derive it is advisable to only produce a single CBOR data item. Tagging, maps or arrays can and should be used for multiple values.

Required Methods

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Encode a value of this type using the given Encoder.

In addition to the encoder a user provided encoding context is given as another parameter. Most implementations of this trait do not need an encoding context and should be completely generic in the context type. In cases where a context is needed and the Encode impl type is meant to be combined with other types that require a different context type, it is preferrable to constrain the context type variable C with a trait bound instead of fixing the type.

Provided Methods

fn is_nil(&self) -> bool

Is this value of Self a nil value?

This method is primarily used by minicbor-derive.

Some types have a special value to denote the concept of “nothing”, aka nil. An example is the Option type with its None value. This method–if overriden–allows checking if a value is such a special nil value.

NB: A type implementing Encode with an overriden Encode::is_nil method should also override Decode::nil if it implements Decode at all.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl Encode<()> for AddrDistr

Source

fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut (), ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<'b, Ctx> Encode<Ctx> for MintedBlock<'b>

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<'b, Ctx> Encode<Ctx> for MintedTx<'b>

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<'b, Ctx> Encode<Ctx> for MintedWitnessSet<'b>

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<'b, Ctx> Encode<Ctx> for MintedWitnessSet<'b>

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<'b, Ctx> Encode<Ctx> for MintedBlock<'b>

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<'b, Ctx> Encode<Ctx> for MintedBlockBody<'b>

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<'b, Ctx> Encode<Ctx> for MintedEbBlock<'b>

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<'b, Ctx> Encode<Ctx> for MintedTxPayload<'b>

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<'b, Ctx> Encode<Ctx> for MintedWitnessSet<'b>

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<C> Encode<C> for IpAddr

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for SocketAddr

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for SpendingData

Source

fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for AnyUInt

Source

fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for AuxiliaryData

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Certificate

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for InstantaneousRewardSource

Source

fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for InstantaneousRewardTarget

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Value

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for BlockSig

Source

fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Ssc

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for SscProof

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Twit

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for TxFeePol

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for TxIn

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Metadatum

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for bool

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for char

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for f32

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for f64

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for i8

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for i16

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for i32

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for i64

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for isize

Available on 32-bit only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for str

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for u8

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for u16

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for u32

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for u64

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for ()

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for usize

Available on 32-bit only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for CString

Available on crate feature alloc only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for String

Available on crate feature alloc only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for CStr

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Ipv4Addr

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Ipv6Addr

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for SocketAddrV4

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for SocketAddrV6

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<i8>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<i16>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<i32>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<i64>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<isize>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<u8>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<u16>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<u32>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<u64>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for NonZero<usize>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<bool>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<i8>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<i16>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<i32>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<i64>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<isize>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<u8>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<u16>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<u32>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<u64>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Atomic<usize>

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Duration

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for Path

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for PathBuf

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for SystemTime

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for EmptyMap

Source

fn encode<W>( &self, e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C> Encode<C> for BoundedBytes

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, I, const T: u64> Encode<C> for TagWrap<I, T>
where I: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, K, V> Encode<C> for KeyValuePairs<K, V>
where K: Encode<C> + Clone, V: Encode<C> + Clone,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, K, V> Encode<C> for NonEmptyKeyValuePairs<K, V>
where K: Encode<C> + Clone, V: Encode<C> + Clone,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, K, V> Encode<C> for BTreeMap<K, V>
where K: Encode<C> + Eq + Ord, V: Encode<C>,

Available on crate feature alloc only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, K, V, S> Encode<C> for HashMap<K, V, S>
where K: Encode<C> + Eq + Hash, V: Encode<C>, S: BuildHasher,

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, P> Encode<C> for OrderPreservingProperties<P>
where P: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for Cow<'_, T>
where T: Encode<C> + ToOwned + ?Sized,

Available on crate feature alloc only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for Bound<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for Option<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

fn is_nil(&self) -> bool

Source

impl<C, T> Encode<C> for Nullable<T>
where T: Encode<C> + Clone,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for PseudoDatumOption<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for PseudoScript<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for PseudoTransactionOutput<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for PseudoScript<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for PseudoTransactionOutput<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for &T
where T: Encode<C> + ?Sized,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for &mut T
where T: Encode<C> + ?Sized,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for [T]
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for Box<T>
where T: Encode<C> + ?Sized,

Available on crate feature alloc only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for BinaryHeap<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for BTreeSet<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for LinkedList<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for VecDeque<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for Vec<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for Cell<T>
where T: Encode<C> + Copy,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for RefCell<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for PhantomData<T>

Source

fn encode<W>( &self, e: &mut Encoder<W>, _: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for Wrapping<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for Range<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for RangeFrom<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for RangeInclusive<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for RangeTo<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for RangeToInclusive<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for CborWrap<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for NonEmptySet<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for Set<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T> Encode<C> for ZeroOrOneArray<T>
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T, E> Encode<C> for Result<T, E>
where T: Encode<C>, E: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T, S> Encode<C> for HashSet<T, S>
where T: Encode<C>, S: BuildHasher,

Available on crate feature std only.
Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, T, const N: usize> Encode<C> for [T; N]
where T: Encode<C>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<C, const N: usize> Encode<C> for SkipCbor<N>

Source

fn encode<W>( &self, _e: &mut Encoder<W>, _ctx: &mut C, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx> Encode<Ctx> for Language

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for RedeemerTag

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Language

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for NonceVariant

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Block

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for HeaderBody

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for MoveInstantaneousReward

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for PostAlonzoAuxiliaryData

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for ProtocolParamUpdate

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Redeemer

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for RedeemerPointer

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for ShelleyMaAuxiliaryData

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for TransactionBody

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for TransactionOutput

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Tx

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Update

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for WitnessSet

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for CostModels

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for OperationalCert

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for PostAlonzoAuxiliaryData

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for ProtocolParamUpdate

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Update

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for WitnessSet

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Address

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for BVerMod

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Block

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for BlockBody

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for BlockCons

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for BlockHead

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for BlockHeadEx

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for BlockProof

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Dlg

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for EbBlock

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for EbbCons

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for EbbHead

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Lwdlg

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for SlotId

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Tx

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for TxOut

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for TxPayload

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Up

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for UpProp

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for UpVote

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for PostAlonzoAuxiliaryData

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for RedeemersValue

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Update

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for WitnessSet

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for ExUnitPrices

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for Nonce

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx> Encode<Ctx> for VrfCert

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx, A> Encode<Ctx> for (A,)
where A: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B> Encode<Ctx> for (A, B)
where A: Encode<Ctx>, B: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C> Encode<Ctx> for (A, B, C)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D> Encode<Ctx> for (A, B, C, D)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E> Encode<Ctx> for (A, B, C, D, E)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F> Encode<Ctx> for (A, B, C, D, E, F)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G> Encode<Ctx> for (A, B, C, D, E, F, G)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G, H> Encode<Ctx> for (A, B, C, D, E, F, G, H)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G, H, I> Encode<Ctx> for (A, B, C, D, E, F, G, H, I)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G, H, I, J> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G, H, I, J, K> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>, M: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>, M: Encode<Ctx>, N: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>, M: Encode<Ctx>, N: Encode<Ctx>, O: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> Encode<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)
where A: Encode<Ctx>, B: Encode<Ctx>, C: Encode<Ctx>, D: Encode<Ctx>, E: Encode<Ctx>, F: Encode<Ctx>, G: Encode<Ctx>, H: Encode<Ctx>, I: Encode<Ctx>, J: Encode<Ctx>, K: Encode<Ctx>, L: Encode<Ctx>, M: Encode<Ctx>, N: Encode<Ctx>, O: Encode<Ctx>, P: Encode<Ctx>,

Source

fn encode<W>( &self, e: &mut Encoder<W>, ctx: &mut Ctx, ) -> Result<(), Error<<W as Write>::Error>>
where W: Write,

Source

impl<Ctx, T1> Encode<Ctx> for PseudoHeader<T1>
where T1: Encode<Ctx>,

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx, T1> Encode<Ctx> for PseudoHeader<T1>
where T1: Encode<Ctx>,

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx, T1> Encode<Ctx> for PseudoTransactionBody<T1>
where T1: Encode<Ctx>,

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx, T1> Encode<Ctx> for PseudoTransactionBody<T1>
where T1: Encode<Ctx>,

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx, T1, T2, T3> Encode<Ctx> for PseudoPostAlonzoTransactionOutput<T1, T2, T3>
where T1: Encode<Ctx>, T2: Encode<Ctx>, T3: Encode<Ctx>,

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx, T1, T2, T3> Encode<Ctx> for PseudoTx<T1, T2, T3>
where T1: Encode<Ctx> + Clone, T2: Encode<Ctx> + Clone, T3: Encode<Ctx> + Clone,

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx, T1, T2, T3> Encode<Ctx> for PseudoTx<T1, T2, T3>
where T1: Encode<Ctx> + Clone, T2: Encode<Ctx> + Clone, T3: Encode<Ctx> + Clone,

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx, T1, T2, T3, T4> Encode<Ctx> for PseudoBlock<T1, T2, T3, T4>
where T1: Encode<Ctx>, T2: Encode<Ctx>, T3: Encode<Ctx>, T4: Encode<Ctx> + Clone,

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Source

impl<Ctx, T1, T2, T3, T4> Encode<Ctx> for PseudoBlock<T1, T2, T3, T4>
where T1: Encode<Ctx>, T2: Encode<Ctx>, T3: Encode<Ctx>, T4: Encode<Ctx> + Clone,

Source

fn encode<__W777>( &self, __e777: &mut Encoder<__W777>, __ctx777: &mut Ctx, ) -> Result<(), Error<<__W777 as Write>::Error>>
where __W777: Write,

Implementors

Source

impl Encode<()> for Point

Source

impl Encode<()> for NetworkBlock

Source

impl Encode<()> for Tip

Source

impl<'b, C> Encode<C> for Token<'b>

Source

impl<C> Encode<C> for ConstitutionalCommitteeStatus

Source

impl<C> Encode<C> for EraName

Source

impl<C> Encode<C> for MemoizedDatum

Source

impl<C> Encode<C> for amaru_kernel::cardano::metadatum::Metadatum

Source

impl<C> Encode<C> for AddrAttrProperty

Source

impl<C> Encode<C> for AddrType

Source

impl<C> Encode<C> for BigInt

Source

impl<C> Encode<C> for amaru_kernel::Certificate

Source

impl<C> Encode<C> for DRep

Source

impl<C> Encode<C> for GovAction

Source

impl<C> Encode<C> for NativeScript

Source

impl<C> Encode<C> for PlutusData

Source

impl<C> Encode<C> for Redeemers

Source

impl<C> Encode<C> for Relay

Source

impl<C> Encode<C> for StakeCredential

Source

impl<C> Encode<C> for amaru_kernel::Value

Source

impl<C> Encode<C> for Vote

Source

impl<C> Encode<C> for Voter

Source

impl<C> Encode<C> for IanaTag

Source

impl<C> Encode<C> for Ballot

Source

impl<C> Encode<C> for BallotId

Source

impl<C> Encode<C> for BlockHeader

Source

impl<C> Encode<C> for BlockHeight

Source

impl<C> Encode<C> for CertificatePointer

Source

impl<C> Encode<C> for Epoch

Source

impl<C> Encode<C> for EraBound

Source

impl<C> Encode<C> for EraHistory

Source

impl<C> Encode<C> for EraParams

Source

impl<C> Encode<C> for EraSummary

Source

impl<C> Encode<C> for MemoizedNativeScript

Source

impl<C> Encode<C> for MemoizedPlutusData

Source

impl<C> Encode<C> for MemoizedTransactionOutput

Source

impl<C> Encode<C> for NetworkMagic

Source

impl<C> Encode<C> for PoolParams

Source

impl<C> Encode<C> for ComparableProposalId

Source

impl<C> Encode<C> for ProposalPointer

Source

impl<C> Encode<C> for ProtocolParameters

Source

impl<C> Encode<C> for Slot

Source

impl<C> Encode<C> for TransactionPointer

Source

impl<C> Encode<C> for Anchor

Source

impl<C> Encode<C> for Constitution

Source

impl<C> Encode<C> for DRepVotingThresholds

Source

impl<C> Encode<C> for NonZeroInt

Source

impl<C> Encode<C> for PoolVotingThresholds

Source

impl<C> Encode<C> for PositiveCoin

Source

impl<C> Encode<C> for ProposalProcedure

Source

impl<C> Encode<C> for GovActionId

Source

impl<C> Encode<C> for RationalNumber

Source

impl<C> Encode<C> for VotingProcedure

Source

impl<C> Encode<C> for SerialisedAsMillis

Source

impl<C> Encode<C> for SerialisedAsPico

Source

impl<C> Encode<C> for ByteSlice

Source

impl<C> Encode<C> for ByteVec

Available on crate feature alloc only.
Source

impl<C> Encode<C> for amaru_kernel::cbor::data::Int

Source

impl<C> Encode<C> for AnyCbor

Source

impl<C> Encode<C> for Tag

Source

impl<C, A> Encode<C> for MaybeIndefArray<A>
where A: Encode<C>,

Source

impl<C, A> Encode<C> for Constr<A>
where A: Encode<C>,

Source

impl<C, I, K, V> Encode<C> for MapIter<I>
where I: Iterator<Item = (K, V)> + Clone, K: Encode<C>, V: Encode<C>,

Source

impl<C, I, T> Encode<C> for ArrayIter<I>
where I: Iterator<Item = T> + Clone, T: Encode<C>,

Source

impl<C, T> Encode<C> for KeepRaw<'_, T>

Source

impl<C, const BYTES: usize> Encode<C> for Hash<BYTES>

Source

impl<C, const N: u64, T> Encode<C> for Tagged<N, T>
where T: Encode<C>,

Source

impl<C, const N: usize> Encode<C> for ByteArray<N>

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::Language

Source

impl<Ctx> Encode<Ctx> for NetworkId

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::ScriptPurpose

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::cardano::auxiliary_data::AuxiliaryData

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::cardano::block::Block

Source

impl<Ctx> Encode<Ctx> for Transaction

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::cardano::transaction_body::TransactionBody

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::cardano::witness_set::WitnessSet

Source

impl<Ctx> Encode<Ctx> for AddressPayload

Source

impl<Ctx> Encode<Ctx> for BootstrapWitness

Source

impl<Ctx> Encode<Ctx> for ByronAddress

Source

impl<Ctx> Encode<Ctx> for Bytes

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::CostModels

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::ExUnitPrices

Source

impl<Ctx> Encode<Ctx> for ExUnits

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::HeaderBody

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::Int

Source

impl<Ctx> Encode<Ctx> for PoolMetadata

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::ProtocolParamUpdate

Source

impl<Ctx> Encode<Ctx> for amaru_kernel::Redeemer

Source

impl<Ctx> Encode<Ctx> for RedeemersKey

Source

impl<Ctx> Encode<Ctx> for TransactionInput

Source

impl<Ctx> Encode<Ctx> for VKeyWitness

Source

impl<Ctx, const VERSION: usize> Encode<Ctx> for PlutusScript<VERSION>