Module cbor

Module cbor 

Structs

SerialisedAsMillis
A newtype wrapper meant to facilitate encoding of time::Duration as integers with millis precision. This may seem odd, but is necessary to mimicks the encoding behavior of some Haskell types such as ‘SlotLength’.
SerialisedAsPico
A newtype wrapper meant to facilitate CBOR encoding of time::Duration as integers with pico-precision. This may seem odd, but is necessary to mimic the encoding behavior of some Haskell types such as ‘RelativeTime’.