SerialisedAsMillis

Struct SerialisedAsMillis 

pub struct SerialisedAsMillis(/* private fields */);
A newtype wrapper meant to facilitate encoding of time::Duration as integers with millis precision. This may seem odd, but is necessary to mimicks the encoding behavior of some Haskell types such as ‘SlotLength’.

Note that there is a loss of precision coming from this type when durations are below milliseconds. In practice, this type is used to represent seconds or tenth of seconds.

Implementations

Source

impl SerialisedAsMillis

pub fn deserialize<'de, D>(deserializer: D) -> Result<Duration, D::Error>
where D: Deserializer<'de>,

pub fn serialize<S>( duration: &Duration, serializer: S, ) -> Result<S::Ok, S::Error>
where S: Serializer,