pub enum NetworkName {
Mainnet,
Preprod,
Preview,
Testnet(u32),
}Variants
Implementations
Sourceimpl NetworkName
impl NetworkName
pub fn to_network_magic(self) -> NetworkMagic
Sourcepub fn default_epoch_size_in_slots(&self) -> u64
pub fn default_epoch_size_in_slots(&self) -> u64
Compute the default epoch length for this network.
This is an over-simplification as theoretically each era can have a different epoch length but in practice, except for Byron era, all eras for each network have always had the same length
Sourcepub fn default_stability_window(&self) -> Slot
pub fn default_stability_window(&self) -> Slot
Provide stability window for given network.