pub struct GlobalParameters {
pub consensus_security_param: usize,
pub epoch_length_scale_factor: usize,
pub active_slot_coeff_inverse: usize,
pub max_lovelace_supply: Lovelace,
pub slots_per_kes_period: u64,
pub max_kes_evolution: u8,
pub epoch_length: usize,
pub stability_window: Slot,
pub randomness_stabilization_window: u64,
pub system_start: u64,
}Fields
consensus_security_param: usizeThe maximum depth of a rollback, also known as the security parameter ‘k’. This translates down to the length of our volatile storage, containing states of the ledger which aren’t yet considered final.
epoch_length_scale_factor: usizeMultiplier applied to the CONSENSUS_SECURITY_PARAM to determine the epoch length.
active_slot_coeff_inverse: usizeInverse of the active slot coefficient (i.e. 1/f);
max_lovelace_supply: LovelaceMaximum supply of Ada, in lovelace (1 Ada = 1,000,000 Lovelace)
slots_per_kes_period: u64Number of slots for a single KES validity period.
max_kes_evolution: u8Maximum number of KES key evolution. Combined with SLOTS_PER_KES_PERIOD, these values indicates the validity period of a KES key before a new one is required.
epoch_length: usizeNumber of slots in an epoch
stability_window: SlotRelative slot from which data of the previous epoch can be considered stable.
randomness_stabilization_window: u64Number of slots at the end of each epoch which do NOT contribute randomness to the candidate nonce of the following epoch.
system_start: u64POSIX time (milliseconds) of the System Start.