pub struct WitnessSet {
pub vkeywitness: Option<NonEmptyVec<VKeyWitness>>,
pub native_script: Option<NonEmptyVec<MemoizedNativeScript>>,
pub bootstrap_witness: Option<NonEmptyVec<BootstrapWitness>>,
pub plutus_v1_script: Option<NonEmptyVec<PlutusScript<1>>>,
pub plutus_data: Option<NonEmptyVec<MemoizedPlutusData>>,
pub redeemer: Option<Redeemers>,
pub plutus_v2_script: Option<NonEmptyVec<PlutusScript<2>>>,
pub plutus_v3_script: Option<NonEmptyVec<PlutusScript<3>>>,
}Expand description
FIXME: Accidentally not a set
NonEmptyVec below are supposed to be a NonEmptySet where duplicates would fail to decode. But it isn’t. In the Haskell’s codebsae, the default decoder for Set fails on duplicate starting from v9 and above:
However, the decoders for witnesses fields were (accidentally) overridden and did not use the
default Set implementation. So, duplicates were silently ignored instead of leading to
decoder failure (while still allowing a set tag, and still expecting at least one element):
Importantly, this behaviour is changing again in v12, back to being a non-empty set / maps.
Fields
vkeywitness: Option<NonEmptyVec<VKeyWitness>>native_script: Option<NonEmptyVec<MemoizedNativeScript>>bootstrap_witness: Option<NonEmptyVec<BootstrapWitness>>FIXME: Accidentally not a set
See note on vkeywitness.
plutus_v1_script: Option<NonEmptyVec<PlutusScript<1>>>plutus_data: Option<NonEmptyVec<MemoizedPlutusData>>redeemer: Option<Redeemers>plutus_v2_script: Option<NonEmptyVec<PlutusScript<2>>>plutus_v3_script: Option<NonEmptyVec<PlutusScript<3>>>Implementations
Sourceimpl WitnessSet
impl WitnessSet
Sourcepub fn get_provided_scripts(&self) -> BTreeMap<Hash<SCRIPT>, ScriptKind>
pub fn get_provided_scripts(&self) -> BTreeMap<Hash<SCRIPT>, ScriptKind>
Collect provided scripts and compute each ScriptHash in a witness set