pub trait CborLen<C> {
// Required method
fn cbor_len(&self, ctx: &mut C) -> usize;
}Expand description
A type that can calculate its own CBOR encoding length.
Required Methods
Implementations on Foreign Types
Sourceimpl<C> CborLen<C> for SocketAddr
Available on crate feature std only.
impl<C> CborLen<C> for SocketAddr
Available on crate feature
std only.Sourceimpl<C> CborLen<C> for SocketAddrV4
Available on crate feature std only.
impl<C> CborLen<C> for SocketAddrV4
Available on crate feature
std only.Sourceimpl<C> CborLen<C> for SocketAddrV6
Available on crate feature std only.
impl<C> CborLen<C> for SocketAddrV6
Available on crate feature
std only.Sourceimpl<C> CborLen<C> for SystemTime
Available on crate feature std only.
impl<C> CborLen<C> for SystemTime
Available on crate feature
std only.Sourceimpl<C, T> CborLen<C> for BinaryHeap<T>where
T: CborLen<C>,
impl<C, T> CborLen<C> for BinaryHeap<T>where
T: CborLen<C>,
Sourceimpl<C, T> CborLen<C> for LinkedList<T>where
T: CborLen<C>,
impl<C, T> CborLen<C> for LinkedList<T>where
T: CborLen<C>,
Sourceimpl<C, T> CborLen<C> for RangeInclusive<T>where
T: CborLen<C>,
impl<C, T> CborLen<C> for RangeInclusive<T>where
T: CborLen<C>,
Sourceimpl<C, T> CborLen<C> for RangeToInclusive<T>where
T: CborLen<C>,
impl<C, T> CborLen<C> for RangeToInclusive<T>where
T: CborLen<C>,
Sourceimpl<C, T, S> CborLen<C> for HashSet<T, S>where
T: CborLen<C>,
S: BuildHasher,
Available on crate feature std only.
impl<C, T, S> CborLen<C> for HashSet<T, S>where
T: CborLen<C>,
S: BuildHasher,
Available on crate feature
std only.Sourceimpl<Ctx, A, B, C, D> CborLen<Ctx> for (A, B, C, D)
impl<Ctx, A, B, C, D> CborLen<Ctx> for (A, B, C, D)
Sourceimpl<Ctx, A, B, C, D, E> CborLen<Ctx> for (A, B, C, D, E)
impl<Ctx, A, B, C, D, E> CborLen<Ctx> for (A, B, C, D, E)
Sourceimpl<Ctx, A, B, C, D, E, F> CborLen<Ctx> for (A, B, C, D, E, F)
impl<Ctx, A, B, C, D, E, F> CborLen<Ctx> for (A, B, C, D, E, F)
Sourceimpl<Ctx, A, B, C, D, E, F, G> CborLen<Ctx> for (A, B, C, D, E, F, G)
impl<Ctx, A, B, C, D, E, F, G> CborLen<Ctx> for (A, B, C, D, E, F, G)
Sourceimpl<Ctx, A, B, C, D, E, F, G, H> CborLen<Ctx> for (A, B, C, D, E, F, G, H)
impl<Ctx, A, B, C, D, E, F, G, H> CborLen<Ctx> for (A, B, C, D, E, F, G, H)
Sourceimpl<Ctx, A, B, C, D, E, F, G, H, I> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I)
impl<Ctx, A, B, C, D, E, F, G, H, I> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I)
Sourceimpl<Ctx, A, B, C, D, E, F, G, H, I, J> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J)
impl<Ctx, A, B, C, D, E, F, G, H, I, J> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J)
Sourceimpl<Ctx, A, B, C, D, E, F, G, H, I, J, K> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K)
impl<Ctx, A, B, C, D, E, F, G, H, I, J, K> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K)
Sourceimpl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L)
impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L)
Sourceimpl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M)
impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M)
Sourceimpl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)
Sourceimpl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)
Sourceimpl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)
impl<Ctx, A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> CborLen<Ctx> for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)
Implementors
impl<'b, C> CborLen<C> for Token<'b>
impl<C> CborLen<C> for IanaTag
impl<C> CborLen<C> for ByteSlice
impl<C> CborLen<C> for ByteVec
Available on crate feature
alloc only.