pub struct LazyDecoder<'a> { /* private fields */ }Expand description
A decoder that only consumes bytes CHUNK_SIZE at a time. Useful to decode large files while maintaining memory usage low.
The decoder keeps an internal state with the bytes that have been read but not consumed, and a
handle to a source that implements std::io::Read.
See Self::from_file for example, to lazily read and decode from a (large) file.
Implementations
Sourceimpl<'a> LazyDecoder<'a>
impl<'a> LazyDecoder<'a>