macro_rules! prop_cbor_roundtrip {
($title:ident, $ty:ty, $strategy:expr) => { ... };
($ty:ty, $strategy:expr) => { ... };
}Expand description
Generate a roundtrip property to assert that Cbor encoder and decoder for a given type can safely be called in sequence and yield the original input.
Requires:
- proptest
Usage: