pub struct Hasher<const BITS: usize>(/* private fields */);Expand description
handy method to create a hash of given SIZE bit size.
The hash algorithm is Blake2b and the constant parameter is
the number of bits to generate. Good values are 256 or 224 for
Cardano.
Generate a cryptographic hash with Blake2b 256
The following will generate a 32 bytes digest output
let mut hasher = Hasher::<256>::new();
hasher.input(b"My transaction");
let digest = hasher.finalize();Generate a cryptographic hash with Blake2b 224
The following will generate a 28 bytes digest output. This is used to generate the hash of public keys for addresses.
let digest = Hasher::<224>::hash(b"My Public Key");Implementations
Sourceimpl Hasher<160>
impl Hasher<160>
Sourcepub fn hash(
bytes: &[u8],
) -> Hash<pallas_crypto::::hash::hasher::{impl#2}::hash::{constant#0}>
pub fn hash( bytes: &[u8], ) -> Hash<pallas_crypto::::hash::hasher::{impl#2}::hash::{constant#0}>
convenient function to directly generate the hash
of the given bytes without creating the intermediary
types Hasher and calling Hasher::input.
pub fn hash_tagged( bytes: &[u8], tag: u8, ) -> Hash<pallas_crypto::::hash::hasher::{impl#2}::hash_tagged::{constant#0}>
Sourcepub fn hash_cbor(
data: &impl Encode<()>,
) -> Hash<pallas_crypto::::hash::hasher::{impl#2}::hash_cbor::{constant#0}>
pub fn hash_cbor( data: &impl Encode<()>, ) -> Hash<pallas_crypto::::hash::hasher::{impl#2}::hash_cbor::{constant#0}>
convenient function to directly generate the hash of the given minicbor::Encode data object
pub fn hash_tagged_cbor( data: &impl Encode<()>, tag: u8, ) -> Hash<pallas_crypto::::hash::hasher::{impl#2}::hash_tagged_cbor::{constant#0}>
Sourceimpl Hasher<224>
impl Hasher<224>
Sourcepub fn hash(
bytes: &[u8],
) -> Hash<pallas_crypto::::hash::hasher::{impl#4}::hash::{constant#0}>
pub fn hash( bytes: &[u8], ) -> Hash<pallas_crypto::::hash::hasher::{impl#4}::hash::{constant#0}>
convenient function to directly generate the hash
of the given bytes without creating the intermediary
types Hasher and calling Hasher::input.
pub fn hash_tagged( bytes: &[u8], tag: u8, ) -> Hash<pallas_crypto::::hash::hasher::{impl#4}::hash_tagged::{constant#0}>
Sourcepub fn hash_cbor(
data: &impl Encode<()>,
) -> Hash<pallas_crypto::::hash::hasher::{impl#4}::hash_cbor::{constant#0}>
pub fn hash_cbor( data: &impl Encode<()>, ) -> Hash<pallas_crypto::::hash::hasher::{impl#4}::hash_cbor::{constant#0}>
convenient function to directly generate the hash of the given minicbor::Encode data object
pub fn hash_tagged_cbor( data: &impl Encode<()>, tag: u8, ) -> Hash<pallas_crypto::::hash::hasher::{impl#4}::hash_tagged_cbor::{constant#0}>
Sourceimpl Hasher<256>
impl Hasher<256>
Sourcepub fn hash(
bytes: &[u8],
) -> Hash<pallas_crypto::::hash::hasher::{impl#6}::hash::{constant#0}>
pub fn hash( bytes: &[u8], ) -> Hash<pallas_crypto::::hash::hasher::{impl#6}::hash::{constant#0}>
convenient function to directly generate the hash
of the given bytes without creating the intermediary
types Hasher and calling Hasher::input.
pub fn hash_tagged( bytes: &[u8], tag: u8, ) -> Hash<pallas_crypto::::hash::hasher::{impl#6}::hash_tagged::{constant#0}>
Sourcepub fn hash_cbor(
data: &impl Encode<()>,
) -> Hash<pallas_crypto::::hash::hasher::{impl#6}::hash_cbor::{constant#0}>
pub fn hash_cbor( data: &impl Encode<()>, ) -> Hash<pallas_crypto::::hash::hasher::{impl#6}::hash_cbor::{constant#0}>
convenient function to directly generate the hash of the given minicbor::Encode data object
pub fn hash_tagged_cbor( data: &impl Encode<()>, tag: u8, ) -> Hash<pallas_crypto::::hash::hasher::{impl#6}::hash_tagged_cbor::{constant#0}>