pub struct SerialisedAsPico(/* private fields */);Expand description
A newtype wrapper meant to facilitate CBOR encoding of time::Duration as integers with pico-precision. This may seem odd, but is necessary to mimic the encoding behavior of some Haskell types such as ‘RelativeTime’.
Note that the Haskell RelativeTime truncates to whole seconds, which this helper does not. Haskell should be able to read values encoded by this helper, but will truncate to whole seconds when computing with the values.
TODO: Maybe consider promoting this as RelativeTime, for robustness and to avoid some
confusing naming…
Implementations
Sourceimpl SerialisedAsPico
impl SerialisedAsPico
pub fn deserialize<'de, D>(deserializer: D) -> Result<Duration, D::Error>where
D: Deserializer<'de>,
pub fn serialize<S>(
duration: &Duration,
serializer: S,
) -> Result<S::Ok, S::Error>where
S: Serializer,